@@ -10,6 +10,7 @@ import re
 import logging
 import socket
 import sys
+import os
 import time
 import threading
 from Pyro4.errors import NamingError, PyroError, ProtocolError
@@ -547,8 +548,15 @@ def main(args=None):
     parser.add_option("", "--natport", dest="natport", type="int", help="external port in case of NAT")
     parser.add_option("-x", "--nobc", dest="enablebc", action="store_false", default=True,
                       help="don't start a broadcast server")
-    parser.add_option("-k", "--key", help="the HMAC key to use")
+    parser.add_option("-k", "--key", help="the HMAC key to use (deprecated)")
     options, args = parser.parse_args(args)
+    if options.key:
+        warnings.warn("using -k to supply HMAC key on the command line is a security problem "
+                      "and is deprecated since Pyro 4.72. See the documentation for an alternative.")
+    if "PYRO_HMAC_KEY" in os.environ:
+        if options.key:
+            raise SystemExit("error: don't use -k and PYRO_HMAC_KEY at the same time")
+        options.key = os.environ["PYRO_HMAC_KEY"]
     startNSloop(options.host, options.port, enableBroadcast=options.enablebc,
                 bchost=options.bchost, bcport=options.bcport, unixsocket=options.unixsocket,
                 nathost=options.nathost, natport=options.natport, storage=options.storage,
